/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_sr_Latn extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_ccp = "\u010dakma";
        final String metaValue_chr = "\u010deroki";
        final String metaValue_nqo = "nko";
        final String metaValue_vai = "vai";
        final Object[][] data = new Object[][] {
            { "001", "svet" },
            { "002", "Afrika" },
            { "003", "Severnoameri\u010dki kontinent" },
            { "005", "Ju\u017ena Amerika" },
            { "009", "Okeanija" },
            { "011", "Zapadna Afrika" },
            { "013", "Centralna Amerika" },
            { "014", "Isto\u010dna Afrika" },
            { "015", "Severna Afrika" },
            { "017", "Centralna Afrika" },
            { "018", "Ju\u017ena Afrika" },
            { "019", "Severna i Ju\u017ena Amerika" },
            { "021", "Severna Amerika" },
            { "029", "Karibi" },
            { "030", "Isto\u010dna Azija" },
            { "034", "Ju\u017ena Azija" },
            { "035", "Jugoisto\u010dna Azija" },
            { "039", "Ju\u017ena Evropa" },
            { "053", "Australija i Novi Zeland" },
            { "054", "Melanezija" },
            { "057", "Mikronezijski region" },
            { "061", "Polinezija" },
            { "142", "Azija" },
            { "143", "Centralna Azija" },
            { "145", "Zapadna Azija" },
            { "150", "Evropa" },
            { "151", "Isto\u010dna Evropa" },
            { "154", "Severna Evropa" },
            { "155", "Zapadna Evropa" },
            { "202", "Podsaharska Afrika" },
            { "419", "Latinska Amerika" },
            { "AC", "Ostrvo Asension" },
            { "AD", "Andora" },
            { "AE", "Ujedinjeni Arapski Emirati" },
            { "AF", "Avganistan" },
            { "AG", "Antigva i Barbuda" },
            { "AI", "Angvila" },
            { "AL", "Albanija" },
            { "AM", "Jermenija" },
            { "AO", "Angola" },
            { "AQ", "Antarktik" },
            { "AR", "Argentina" },
            { "AS", "Ameri\u010dka Samoa" },
            { "AT", "Austrija" },
            { "AU", "Australija" },
            { "AW", "Aruba" },
            { "AX", "Olandska Ostrva" },
            { "AZ", "Azerbejd\u017ean" },
            { "BA", "Bosna i Hercegovina" },
            { "BB", "Barbados" },
            { "BD", "Banglade\u0161" },
            { "BE", "Belgija" },
            { "BF", "Burkina Faso" },
            { "BG", "Bugarska" },
            { "BH", "Bahrein" },
            { "BI", "Burundi" },
            { "BJ", "Benin" },
            { "BL", "Sveti Bartolomej" },
            { "BM", "Bermuda" },
            { "BN", "Brunej" },
            { "BO", "Bolivija" },
            { "BQ", "Karipska Holandija" },
            { "BR", "Brazil" },
            { "BS", "Bahami" },
            { "BT", "Butan" },
            { "BV", "Ostrvo Buve" },
            { "BW", "Bocvana" },
            { "BY", "Belorusija" },
            { "BZ", "Belize" },
            { "CA", "Kanada" },
            { "CC", "Kokosova (Kilingova) Ostrva" },
            { "CD", "Kongo - Kin\u0161asa" },
            { "CF", "Centralnoafri\u010dka Republika" },
            { "CG", "Kongo - Brazavil" },
            { "CH", "\u0160vajcarska" },
            { "CI", "Obala Slonova\u010de (Kot d\u2019Ivoar)" },
            { "CK", "Kukova Ostrva" },
            { "CL", "\u010cile" },
            { "CM", "Kamerun" },
            { "CN", "Kina" },
            { "CO", "Kolumbija" },
            { "CP", "Ostrvo Kliperton" },
            { "CR", "Kostarika" },
            { "CU", "Kuba" },
            { "CV", "Zelenortska Ostrva" },
            { "CW", "Kurasao" },
            { "CX", "Bo\u017ei\u0107no Ostrvo" },
            { "CY", "Kipar" },
            { "CZ", "\u010ce\u0161ka" },
            { "DE", "Nema\u010dka" },
            { "DG", "Dijego Garsija" },
            { "DJ", "D\u017eibuti" },
            { "DK", "Danska" },
            { "DM", "Dominika" },
            { "DO", "Dominikanska Republika" },
            { "DZ", "Al\u017eir" },
            { "EA", "Seuta i Melilja" },
            { "EC", "Ekvador" },
            { "EE", "Estonija" },
            { "EG", "Egipat" },
            { "EH", "Zapadna Sahara" },
            { "ER", "Eritreja" },
            { "ES", "\u0160panija" },
            { "ET", "Etiopija" },
            { "EU", "Evropska unija" },
            { "EZ", "Evrozona" },
            { "FI", "Finska" },
            { "FJ", "Fid\u017ei" },
            { "FK", "Foklandska Ostrva" },
            { "FM", "Mikronezija" },
            { "FO", "Farska Ostrva" },
            { "FR", "Francuska" },
            { "GA", "Gabon" },
            { "GB", "Ujedinjeno Kraljevstvo" },
            { "GD", "Grenada" },
            { "GE", "Gruzija" },
            { "GF", "Francuska Gvajana" },
            { "GG", "Gernzi" },
            { "GH", "Gana" },
            { "GI", "Gibraltar" },
            { "GL", "Grenland" },
            { "GM", "Gambija" },
            { "GN", "Gvineja" },
            { "GP", "Gvadelup" },
            { "GQ", "Ekvatorijalna Gvineja" },
            { "GR", "Gr\u010dka" },
            { "GS", "Ju\u017ena D\u017eord\u017eija i Ju\u017ena Sendvi\u010dka Ostrva" },
            { "GT", "Gvatemala" },
            { "GU", "Guam" },
            { "GW", "Gvineja-Bisao" },
            { "GY", "Gvajana" },
            { "HK", "SAR Hongkong (Kina)" },
            { "HM", "Ostrvo Herd i Mekdonaldova ostrva" },
            { "HN", "Honduras" },
            { "HR", "Hrvatska" },
            { "HT", "Haiti" },
            { "HU", "Ma\u0111arska" },
            { "IC", "Kanarska Ostrva" },
            { "ID", "Indonezija" },
            { "IE", "Irska" },
            { "IL", "Izrael" },
            { "IM", "Ostrvo Man" },
            { "IN", "Indija" },
            { "IO", "Britanska teritorija Indijskog okeana" },
            { "IQ", "Irak" },
            { "IR", "Iran" },
            { "IS", "Island" },
            { "IT", "Italija" },
            { "JE", "D\u017eerzi" },
            { "JM", "Jamajka" },
            { "JO", "Jordan" },
            { "JP", "Japan" },
            { "KE", "Kenija" },
            { "KG", "Kirgistan" },
            { "KH", "Kambod\u017ea" },
            { "KI", "Kiribati" },
            { "KM", "Komorska Ostrva" },
            { "KN", "Sent Kits i Nevis" },
            { "KP", "Severna Koreja" },
            { "KR", "Ju\u017ena Koreja" },
            { "KW", "Kuvajt" },
            { "KY", "Kajmanska Ostrva" },
            { "KZ", "Kazahstan" },
            { "LA", "Laos" },
            { "LB", "Liban" },
            { "LC", "Sveta Lucija" },
            { "LI", "Lihten\u0161tajn" },
            { "LK", "\u0160ri Lanka" },
            { "LR", "Liberija" },
            { "LS", "Lesoto" },
            { "LT", "Litvanija" },
            { "LU", "Luksemburg" },
            { "LV", "Letonija" },
            { "LY", "Libija" },
            { "MA", "Maroko" },
            { "MC", "Monako" },
            { "MD", "Moldavija" },
            { "ME", "Crna Gora" },
            { "MF", "Sveti Martin (Francuska)" },
            { "MG", "Madagaskar" },
            { "MH", "Mar\u0161alska Ostrva" },
            { "MK", "Severna Makedonija" },
            { "ML", "Mali" },
            { "MM", "Mijanmar (Burma)" },
            { "MN", "Mongolija" },
            { "MO", "SAR Makao (Kina)" },
            { "MP", "Severna Marijanska Ostrva" },
            { "MQ", "Martinik" },
            { "MR", "Mauritanija" },
            { "MS", "Monserat" },
            { "MT", "Malta" },
            { "MU", "Mauricijus" },
            { "MV", "Maldivi" },
            { "MW", "Malavi" },
            { "MX", "Meksiko" },
            { "MY", "Malezija" },
            { "MZ", "Mozambik" },
            { "NA", "Namibija" },
            { "NC", "Nova Kaledonija" },
            { "NE", "Niger" },
            { "NF", "Ostrvo Norfok" },
            { "NG", "Nigerija" },
            { "NI", "Nikaragva" },
            { "NL", "Holandija" },
            { "NO", "Norve\u0161ka" },
            { "NP", "Nepal" },
            { "NR", "Nauru" },
            { "NU", "Niue" },
            { "NZ", "Novi Zeland" },
            { "OM", "Oman" },
            { "PA", "Panama" },
            { "PE", "Peru" },
            { "PF", "Francuska Polinezija" },
            { "PG", "Papua Nova Gvineja" },
            { "PH", "Filipini" },
            { "PK", "Pakistan" },
            { "PL", "Poljska" },
            { "PM", "Sen Pjer i Mikelon" },
            { "PN", "Pitkern" },
            { "PR", "Portoriko" },
            { "PS", "Palestinske teritorije" },
            { "PT", "Portugalija" },
            { "PW", "Palau" },
            { "PY", "Paragvaj" },
            { "QA", "Katar" },
            { "QO", "Okeanija (udaljena ostrva)" },
            { "RE", "Reinion" },
            { "RO", "Rumunija" },
            { "RS", "Srbija" },
            { "RU", "Rusija" },
            { "RW", "Ruanda" },
            { "SA", "Saudijska Arabija" },
            { "SB", "Solomonska Ostrva" },
            { "SC", "Sej\u0161eli" },
            { "SD", "Sudan" },
            { "SE", "\u0160vedska" },
            { "SG", "Singapur" },
            { "SH", "Sveta Jelena" },
            { "SI", "Slovenija" },
            { "SJ", "Svalbard i Jan Majen" },
            { "SK", "Slova\u010dka" },
            { "SL", "Sijera Leone" },
            { "SM", "San Marino" },
            { "SN", "Senegal" },
            { "SO", "Somalija" },
            { "SR", "Surinam" },
            { "SS", "Ju\u017eni Sudan" },
            { "ST", "Sao Tome i Principe" },
            { "SV", "Salvador" },
            { "SX", "Sveti Martin (Holandija)" },
            { "SY", "Sirija" },
            { "SZ", "Svazilend" },
            { "TA", "Tristan da Kunja" },
            { "TC", "Ostrva Turks i Kaikos" },
            { "TD", "\u010cad" },
            { "TF", "Francuske Ju\u017ene Teritorije" },
            { "TG", "Togo" },
            { "TH", "Tajland" },
            { "TJ", "Tad\u017eikistan" },
            { "TK", "Tokelau" },
            { "TL", "Timor-Leste (Isto\u010dni Timor)" },
            { "TM", "Turkmenistan" },
            { "TN", "Tunis" },
            { "TO", "Tonga" },
            { "TR", "Turska" },
            { "TT", "Trinidad i Tobago" },
            { "TV", "Tuvalu" },
            { "TW", "Tajvan" },
            { "TZ", "Tanzanija" },
            { "UA", "Ukrajina" },
            { "UG", "Uganda" },
            { "UM", "Udaljena ostrva SAD" },
            { "UN", "Ujedinjene nacije" },
            { "US", "Sjedinjene Dr\u017eave" },
            { "UY", "Urugvaj" },
            { "UZ", "Uzbekistan" },
            { "VA", "Vatikan" },
            { "VC", "Sent Vinsent i Grenadini" },
            { "VE", "Venecuela" },
            { "VG", "Britanska Devi\u010danska Ostrva" },
            { "VI", "Ameri\u010dka Devi\u010danska Ostrva" },
            { "VN", "Vijetnam" },
            { "VU", "Vanuatu" },
            { "WF", "Valis i Futuna" },
            { "WS", "Samoa" },
            { "XA", "Pseudoakcenti" },
            { "XB", "Pseudobidi" },
            { "XK", "Kosovo" },
            { "YE", "Jemen" },
            { "YT", "Majot" },
            { "ZA", "Ju\u017enoafri\u010dka Republika" },
            { "ZM", "Zambija" },
            { "ZW", "Zimbabve" },
            { "ZZ", "Nepoznat region" },
            { "aa", "afarski" },
            { "ab", "abhaski" },
            { "ae", "avestanski" },
            { "af", "afrikans" },
            { "ak", "akanski" },
            { "am", "amharski" },
            { "an", "aragonski" },
            { "ar", "arapski" },
            { "as", "asamski" },
            { "av", "avarski" },
            { "ay", "ajmara" },
            { "az", "azerbejd\u017eanski" },
            { "ba", "ba\u0161kirski" },
            { "be", "beloruski" },
            { "bg", "bugarski" },
            { "bi", "bislama" },
            { "bm", "bambara" },
            { "bn", "bengalski" },
            { "bo", "tibetanski" },
            { "br", "bretonski" },
            { "bs", "bosanski" },
            { "ca", "katalonski" },
            { "ce", "\u010de\u010denski" },
            { "ch", "\u010damoro" },
            { "co", "korzikanski" },
            { "cr", "kri" },
            { "cs", "\u010de\u0161ki" },
            { "cu", "crkvenoslovenski" },
            { "cv", "\u010duva\u0161ki" },
            { "cy", "vel\u0161ki" },
            { "da", "danski" },
            { "de", "nema\u010dki" },
            { "dv", "maldivski" },
            { "dz", "d\u017eonga" },
            { "ee", "eve" },
            { "el", "gr\u010dki" },
            { "en", "engleski" },
            { "eo", "esperanto" },
            { "es", "\u0161panski" },
            { "et", "estonski" },
            { "eu", "baskijski" },
            { "fa", "persijski" },
            { "ff", "fula" },
            { "fi", "finski" },
            { "fj", "fid\u017eijski" },
            { "fo", "farski" },
            { "fr", "francuski" },
            { "fy", "zapadni frizijski" },
            { "ga", "irski" },
            { "gd", "\u0161kotski gelski" },
            { "gl", "galicijski" },
            { "gn", "gvarani" },
            { "gu", "gud\u017earati" },
            { "gv", "manks" },
            { "ha", "hausa" },
            { "he", "hebrejski" },
            { "hi", "hindi" },
            { "ho", "hiri motu" },
            { "hr", "hrvatski" },
            { "ht", "hai\u0107anski" },
            { "hu", "ma\u0111arski" },
            { "hy", "jermenski" },
            { "hz", "herero" },
            { "ia", "interlingva" },
            { "id", "indone\u017eanski" },
            { "ie", "interlingve" },
            { "ig", "igbo" },
            { "ii", "se\u010duanski ji" },
            { "ik", "inupik" },
            { "io", "ido" },
            { "is", "islandski" },
            { "it", "italijanski" },
            { "iu", "inuktitutski" },
            { "ja", "japanski" },
            { "jv", "javanski" },
            { "ka", "gruzijski" },
            { "kg", "kongo" },
            { "ki", "kikuju" },
            { "kj", "kvanjama" },
            { "kk", "kaza\u0161ki" },
            { "kl", "grenlandski" },
            { "km", "kmerski" },
            { "kn", "kanada" },
            { "ko", "korejski" },
            { "kr", "kanuri" },
            { "ks", "ka\u0161mirski" },
            { "ku", "kurdski" },
            { "kv", "komi" },
            { "kw", "kornvolski" },
            { "ky", "kirgiski" },
            { "la", "latinski" },
            { "lb", "luksembur\u0161ki" },
            { "lg", "ganda" },
            { "li", "limbur\u0161ki" },
            { "ln", "lingala" },
            { "lo", "laoski" },
            { "lt", "litvanski" },
            { "lu", "luba-katanga" },
            { "lv", "letonski" },
            { "mg", "malga\u0161ki" },
            { "mh", "mar\u0161alski" },
            { "mi", "maorski" },
            { "mk", "makedonski" },
            { "ml", "malajalam" },
            { "mn", "mongolski" },
            { "mr", "marati" },
            { "ms", "malajski" },
            { "mt", "malte\u0161ki" },
            { "my", "burmanski" },
            { "na", "nauruski" },
            { "nb", "norve\u0161ki bukmol" },
            { "nd", "severni ndebele" },
            { "ne", "nepalski" },
            { "ng", "ndonga" },
            { "nl", "holandski" },
            { "nn", "norve\u0161ki ninorsk" },
            { "no", "norve\u0161ki" },
            { "nr", "ju\u017eni ndebele" },
            { "nv", "navaho" },
            { "ny", "njand\u017ea" },
            { "oc", "oksitanski" },
            { "oj", "od\u017eibve" },
            { "om", "oromo" },
            { "or", "odija" },
            { "os", "osetinski" },
            { "pa", "pend\u017eapski" },
            { "pi", "pali" },
            { "pl", "poljski" },
            { "ps", "pa\u0161tunski" },
            { "pt", "portugalski" },
            { "qu", "ke\u010dua" },
            { "rm", "roman\u0161" },
            { "rn", "kirundi" },
            { "ro", "rumunski" },
            { "ru", "ruski" },
            { "rw", "kinjaruanda" },
            { "sa", "sanskrit" },
            { "sc", "sardinski" },
            { "sd", "sindi" },
            { "se", "severni sami" },
            { "sg", "sango" },
            { "sh", "srpskohrvatski" },
            { "si", "sinhale\u0161ki" },
            { "sk", "slova\u010dki" },
            { "sl", "slovena\u010dki" },
            { "sm", "samoanski" },
            { "sn", "\u0161ona" },
            { "so", "somalski" },
            { "sq", "albanski" },
            { "sr", "srpski" },
            { "ss", "svazi" },
            { "st", "sesoto" },
            { "su", "sundanski" },
            { "sv", "\u0161vedski" },
            { "sw", "svahili" },
            { "ta", "tamilski" },
            { "te", "telugu" },
            { "tg", "tad\u017ei\u010dki" },
            { "th", "tajski" },
            { "ti", "tigrinja" },
            { "tk", "turkmenski" },
            { "tl", "tagalog" },
            { "tn", "cvana" },
            { "to", "tonganski" },
            { "tr", "turski" },
            { "ts", "conga" },
            { "tt", "tatarski" },
            { "tw", "tvi" },
            { "ty", "tahi\u0107anski" },
            { "ug", "ujgurski" },
            { "uk", "ukrajinski" },
            { "ur", "urdu" },
            { "uz", "uzbe\u010dki" },
            { "ve", "venda" },
            { "vi", "vijetnamski" },
            { "vo", "volapik" },
            { "wa", "valonski" },
            { "wo", "volof" },
            { "xh", "kosa" },
            { "yi", "jidi\u0161" },
            { "yo", "joruba" },
            { "za", "d\u017euan\u0161ki" },
            { "zh", "kineski" },
            { "zu", "zulu" },
            { "ace", "ace\u0161ki" },
            { "ach", "akoli" },
            { "ada", "adangme" },
            { "ady", "adigejski" },
            { "afh", "afrihili" },
            { "agq", "agem" },
            { "ain", "ainu" },
            { "akk", "akadijski" },
            { "ale", "aleutski" },
            { "alt", "ju\u017enoaltajski" },
            { "ang", "staroengleski" },
            { "ann", "obolo" },
            { "anp", "angika" },
            { "arc", "aramejski" },
            { "arn", "mapu\u010de" },
            { "arp", "arapaho" },
            { "ars", "najdiarapski" },
            { "arw", "arava\u010dki" },
            { "asa", "asu" },
            { "ast", "asturijski" },
            { "atj", "atikameku" },
            { "awa", "avadi" },
            { "bal", "belu\u010dki" },
            { "ban", "balijski" },
            { "bas", "basa" },
            { "bej", "bed\u017ea" },
            { "bem", "bemba" },
            { "bez", "bena" },
            { "bgn", "zapadni belu\u010dki" },
            { "bho", "bod\u017epuri" },
            { "bik", "bikol" },
            { "bin", "bini" },
            { "bla", "sisika" },
            { "bra", "braj" },
            { "brx", "bodo" },
            { "bua", "burjatski" },
            { "bug", "bugijski" },
            { "byn", "blinski" },
            { "cad", "kado" },
            { "car", "karipski" },
            { "cay", "kajuga" },
            { "cch", "atsam" },
            { "ccp", metaValue_ccp },
            { "ceb", "sebuanski" },
            { "cgg", "\u010diga" },
            { "chb", "\u010dip\u010da" },
            { "chg", "\u010dagataj" },
            { "chk", "\u010du\u010dki" },
            { "chm", "mari" },
            { "chn", "\u010dinu\u010dki" },
            { "cho", "\u010doktavski" },
            { "chp", "\u010dipevjanski" },
            { "chr", metaValue_chr },
            { "chy", "\u010dejenski" },
            { "ckb", "centralni kurdski" },
            { "clc", "\u010dilkotin" },
            { "cop", "koptski" },
            { "crg", "mi\u010dif" },
            { "crh", "krimskotatarski" },
            { "crj", "jugoisto\u010dni kri" },
            { "crk", "plainskri" },
            { "crl", "severoisto\u010dni kri" },
            { "crm", "muzkri" },
            { "crr", "karolin\u0161ki algonkvijan" },
            { "crs", "sej\u0161elski kreolski francuski" },
            { "csb", "ka\u0161upski" },
            { "csw", "mo\u010dvarni kri" },
            { "dak", "dakota" },
            { "dar", "darginski" },
            { "dav", "taita" },
            { "del", "delaverski" },
            { "den", "slejvi" },
            { "dgr", "dogripski" },
            { "din", "dinka" },
            { "dje", "zarma" },
            { "doi", "dogri" },
            { "dsb", "donjolu\u017ei\u010dkosrpski" },
            { "dua", "duala" },
            { "dum", "srednjeholandski" },
            { "dyo", "d\u017eola fonji" },
            { "dyu", "\u0111ula" },
            { "dzg", "dazaga" },
            { "ebu", "embu" },
            { "efi", "efi\u010dki" },
            { "egy", "staroegipatski" },
            { "eka", "ekad\u017euk" },
            { "elx", "elamitski" },
            { "enm", "srednjeengleski" },
            { "ewo", "evondo" },
            { "fan", "fang" },
            { "fat", "fanti" },
            { "fil", "filipinski" },
            { "fon", "fon" },
            { "frc", "kajunski francuski" },
            { "frm", "srednjefrancuski" },
            { "fro", "starofrancuski" },
            { "frr", "severnofrizijski" },
            { "frs", "isto\u010dnofrizijski" },
            { "fur", "friulski" },
            { "gaa", "ga" },
            { "gag", "gagauz" },
            { "gay", "gajo" },
            { "gba", "gbaja" },
            { "gez", "geez" },
            { "gil", "gilbertski" },
            { "gmh", "srednji visokonema\u010dki" },
            { "goh", "staronema\u010dki" },
            { "gon", "gondi" },
            { "gor", "gorontalo" },
            { "got", "gotski" },
            { "grb", "grebo" },
            { "grc", "starogr\u010dki" },
            { "gsw", "nema\u010dki (\u0160vajcarska)" },
            { "guz", "gusi" },
            { "gwi", "gvi\u010dinski" },
            { "hai", "haida" },
            { "haw", "havajski" },
            { "hax", "ju\u017eni haida" },
            { "hil", "hiligajnonski" },
            { "hit", "hetitski" },
            { "hmn", "hmon\u0161ki" },
            { "hsb", "gornjolu\u017ei\u010dkosrpski" },
            { "hup", "hupa" },
            { "hur", "halkomelem" },
            { "iba", "ibanski" },
            { "ibb", "ibibio" },
            { "ikt", "zapadnokanadski inuktitut" },
            { "ilo", "iloko" },
            { "inh", "ingu\u0161ki" },
            { "jbo", "lo\u017eban" },
            { "jgo", "ngomba" },
            { "jmc", "ma\u010dame" },
            { "jpr", "judeo-persijski" },
            { "jrb", "judeo-arapski" },
            { "kaa", "kara-kalpa\u0161ki" },
            { "kab", "kabile" },
            { "kac", "ka\u010dinski" },
            { "kaj", "d\u017eu" },
            { "kam", "kamba" },
            { "kaw", "kavi" },
            { "kbd", "kabardijski" },
            { "kcg", "tjap" },
            { "kde", "makonde" },
            { "kea", "zelenortski" },
            { "kfo", "koro" },
            { "kgp", "kaingang" },
            { "kha", "kasi" },
            { "kho", "kotane\u0161ki" },
            { "khq", "kojra \u010diini" },
            { "kkj", "kako" },
            { "kln", "kalend\u017einski" },
            { "kmb", "kimbundu" },
            { "koi", "komi-permski" },
            { "kok", "konkani" },
            { "kos", "kosrenski" },
            { "kpe", "kpele" },
            { "krc", "kara\u010dajsko-balkarski" },
            { "kri", "krio" },
            { "krl", "karelski" },
            { "kru", "kuruk" },
            { "ksb", "\u0161ambala" },
            { "ksf", "bafija" },
            { "ksh", "kelnski" },
            { "kum", "kumi\u010dki" },
            { "kut", "kutenaj" },
            { "kwk", "kvakvala" },
            { "lad", "ladino" },
            { "lag", "langi" },
            { "lah", "landa" },
            { "lam", "lamba" },
            { "lez", "lezginski" },
            { "lil", "lilut" },
            { "lkt", "lakota" },
            { "lol", "mongo" },
            { "lou", "luizijanski kreolski" },
            { "loz", "lozi" },
            { "lrc", "severni luri" },
            { "lsm", "samia" },
            { "lua", "luba-lulua" },
            { "lui", "luisenjo" },
            { "lun", "lunda" },
            { "luo", "luo" },
            { "lus", "mizo" },
            { "luy", "lujia" },
            { "mad", "madurski" },
            { "mag", "magahi" },
            { "mai", "maitili" },
            { "mak", "makasarski" },
            { "man", "mandingo" },
            { "mas", "masajski" },
            { "mdf", "mok\u0161a" },
            { "mdr", "mandar" },
            { "men", "mende" },
            { "mer", "meru" },
            { "mfe", "morisjen" },
            { "mga", "srednjeirski" },
            { "mgh", "makuva-mito" },
            { "mgo", "meta" },
            { "mic", "mikmak" },
            { "min", "minangkabau" },
            { "mnc", "mand\u017eurski" },
            { "mni", "manipurski" },
            { "moe", "inuajmun" },
            { "moh", "moho\u010dki" },
            { "mos", "mosi" },
            { "mua", "mundang" },
            { "mul", "Vi\u0161e jezika" },
            { "mus", "kri\u0161ki" },
            { "mwl", "mirandski" },
            { "mwr", "marvari" },
            { "myv", "erzja" },
            { "mzn", "mazanderanski" },
            { "nap", "napuljski" },
            { "naq", "nama" },
            { "nds", "niskonema\u010dki" },
            { "new", "nevari" },
            { "nia", "nias" },
            { "niu", "niuejski" },
            { "nmg", "kvasio" },
            { "nnh", "ngiembun" },
            { "nog", "nogajski" },
            { "non", "staronordijski" },
            { "nqo", metaValue_nqo },
            { "nso", "severni soto" },
            { "nus", "nuer" },
            { "nwc", "klasi\u010dni nevarski" },
            { "nym", "njamvezi" },
            { "nyn", "njankole" },
            { "nyo", "njoro" },
            { "nzi", "nzima" },
            { "ojb", "severozapadni od\u017eibva" },
            { "ojc", "centralni od\u017eibva" },
            { "ojs", "od\u017eikri" },
            { "ojw", "zapadni od\u017eibva" },
            { "oka", "okangan" },
            { "osa", "osage" },
            { "ota", "osmanski turski" },
            { "pag", "pangasinanski" },
            { "pal", "pahlavi" },
            { "pam", "pampanga" },
            { "pap", "papijamento" },
            { "pau", "palauski" },
            { "pcm", "nigerijski pid\u017ein" },
            { "peo", "staropersijski" },
            { "phn", "feni\u010danski" },
            { "pis", "pid\u017ein" },
            { "pon", "ponpejski" },
            { "pqm", "malisepasamakvodi" },
            { "prg", "pruski" },
            { "pro", "starooksitanski" },
            { "quc", "ki\u010de" },
            { "raj", "rad\u017eastanski" },
            { "rap", "rapanui" },
            { "rar", "rarotonganski" },
            { "rhg", "rohingja" },
            { "rof", "rombo" },
            { "rom", "romski" },
            { "rup", "cincarski" },
            { "rwk", "rua" },
            { "sad", "sandave" },
            { "sah", "saha" },
            { "sam", "samarijanski aramejski" },
            { "saq", "samburu" },
            { "sas", "sasak" },
            { "sat", "santali" },
            { "sba", "ngambaj" },
            { "sbp", "sangu" },
            { "scn", "sicilijanski" },
            { "sco", "\u0161kotski" },
            { "sdh", "ju\u017enokurdski" },
            { "seh", "sena" },
            { "sel", "selkupski" },
            { "ses", "kojraboro seni" },
            { "sga", "staroirski" },
            { "shi", "ta\u0161elhit" },
            { "shn", "\u0161anski" },
            { "sid", "sidamo" },
            { "slh", "ju\u017eni la\u0161utsid" },
            { "sma", "ju\u017eni sami" },
            { "smj", "lule sami" },
            { "smn", "inari sami" },
            { "sms", "skolt sami" },
            { "snk", "soninke" },
            { "sog", "sogdijski" },
            { "srn", "sranan tongo" },
            { "srr", "sererski" },
            { "ssy", "saho" },
            { "str", "streicsali\u0161" },
            { "suk", "sukuma" },
            { "sus", "susu" },
            { "sux", "sumerski" },
            { "swb", "komorski" },
            { "syc", "sirija\u010dki" },
            { "syr", "sirijski" },
            { "tce", "ju\u017eni ta\u010don" },
            { "tem", "timne" },
            { "teo", "teso" },
            { "ter", "tereno" },
            { "tet", "tetum" },
            { "tgx", "tagi\u0161" },
            { "tht", "tahltan" },
            { "tig", "tigre" },
            { "tiv", "tiv" },
            { "tkl", "tokelau" },
            { "tlh", "klingonski" },
            { "tli", "tlingit" },
            { "tmh", "tama\u0161ek" },
            { "tog", "njasa tonga" },
            { "tok", "tokipona" },
            { "tpi", "tok pisin" },
            { "trv", "taroko" },
            { "tsi", "cim\u0161ian" },
            { "ttm", "severni tu\u010don" },
            { "tum", "tumbuka" },
            { "tvl", "tuvalu" },
            { "twq", "tasavak" },
            { "tyv", "tuvinski" },
            { "tzm", "centralnoatlaski tamazigt" },
            { "udm", "udmurtski" },
            { "uga", "ugaritski" },
            { "umb", "umbundu" },
            { "und", "nepoznat jezik" },
            { "vai", metaValue_vai },
            { "vot", "vodski" },
            { "vun", "vund\u017eo" },
            { "wae", "valserski" },
            { "wal", "volajta" },
            { "war", "varajski" },
            { "was", "va\u0161o" },
            { "wbp", "varlpiri" },
            { "wuu", "vu kineski" },
            { "xal", "kalmi\u010dki" },
            { "xog", "soga" },
            { "yao", "jao" },
            { "yap", "japski" },
            { "yav", "jangben" },
            { "ybb", "jemba" },
            { "yrl", "ningatu" },
            { "yue", "kantonski" },
            { "zap", "zapote\u010dki" },
            { "zbl", "blisimboli" },
            { "zen", "zenaga" },
            { "zgh", "standardni marokanski tamazigt" },
            { "zun", "zuni" },
            { "zxx", "bez lingvisti\u010dkog sadr\u017eaja" },
            { "zza", "zaza" },
            { "Adlm", "adlam" },
            { "Arab", "arapsko pismo" },
            { "Aran", "nastalik" },
            { "Armi", "imperijsko aramejsko pismo" },
            { "Armn", "jermensko pismo" },
            { "Avst", "avestansko pismo" },
            { "Bali", "balijsko pismo" },
            { "Batk", "batak pismo" },
            { "Beng", "bengalsko pismo" },
            { "Blis", "blisimboli\u010dno pismo" },
            { "Bopo", "bopomofo pismo" },
            { "Brah", "bramansko pismo" },
            { "Brai", "brajevo pismo" },
            { "Bugi", "buginsko pismo" },
            { "Buhd", "buhidsko pismo" },
            { "Cakm", metaValue_ccp },
            { "Cans", "ujedinjeni kanadski aborid\u017einski silabici" },
            { "Cari", "karijsko pismo" },
            { "Cham", "\u010damsko pismo" },
            { "Cher", metaValue_chr },
            { "Cirt", "cirt pismo" },
            { "Copt", "kopti\u010dko pismo" },
            { "Cprt", "kiparsko pismo" },
            { "Cyrl", "\u0107irilica" },
            { "Cyrs", "Staroslovenska crkvena \u0107irilica" },
            { "Deva", "devanagari" },
            { "Dsrt", "Dezeret" },
            { "Egyd", "egipatsko narodno pismo" },
            { "Egyh", "egipatsko hijeratsko pismo" },
            { "Egyp", "egipatski hijeroglifi" },
            { "Ethi", "etiopsko pismo" },
            { "Geok", "gruzijsko khutsuri pismo" },
            { "Geor", "gruzijsko pismo" },
            { "Glag", "glagoljica" },
            { "Goth", "Gotika" },
            { "Grek", "gr\u010dko pismo" },
            { "Gujr", "gud\u017earatsko pismo" },
            { "Guru", "gurmuki pismo" },
            { "Hanb", "hanb" },
            { "Hang", "hangul" },
            { "Hani", "han" },
            { "Hano", "hanuno" },
            { "Hans", "pojednostavljeno kinesko pismo" },
            { "Hant", "tradicionalno kinesko pismo" },
            { "Hebr", "hebrejsko pismo" },
            { "Hira", "hiragana" },
            { "Hmng", "pahav hmong pismo" },
            { "Hrkt", "japanska slogovna pisma" },
            { "Hung", "staroma\u0111arsko pismo" },
            { "Inds", "indu\u0161ko pismo" },
            { "Ital", "stari italik" },
            { "Jamo", "d\u017eamo" },
            { "Java", "javansko pismo" },
            { "Jpan", "japansko pismo" },
            { "Kali", "kajah-li pismo" },
            { "Kana", "katakana" },
            { "Khar", "karo\u0161ti pismo" },
            { "Khmr", "kmersko pismo" },
            { "Knda", "kanada pismo" },
            { "Kore", "korejsko pismo" },
            { "Kthi", "kaiti" },
            { "Lana", "lanna pismo" },
            { "Laoo", "lao\u0161ko pismo" },
            { "Latf", "latinica (fraktur varijanta)" },
            { "Latg", "galska latinica" },
            { "Latn", "latinica" },
            { "Lepc", "lep\u010da pismo" },
            { "Limb", "limbu pismo" },
            { "Lina", "linearno A pismo" },
            { "Linb", "linearno B pismo" },
            { "Lyci", "lisijsko pismo" },
            { "Lydi", "lidijsko pismo" },
            { "Mand", "mandeansko pismo" },
            { "Mani", "manihejsko pismo" },
            { "Maya", "majanski hijeroglifi" },
            { "Mero", "meroitik pismo" },
            { "Mlym", "malajalamsko pismo" },
            { "Mong", "mongolsko pismo" },
            { "Moon", "mese\u010devo pismo" },
            { "Mtei", "meitei majek" },
            { "Mymr", "mijanmarsko pismo" },
            { "Nkoo", metaValue_nqo },
            { "Ogam", "ogamsko pismo" },
            { "Olck", "ol \u010diki" },
            { "Orkh", "orkonsko pismo" },
            { "Orya", "orijansko pismo" },
            { "Osma", "osmanjansko pismo" },
            { "Perm", "staro permiksko pismo" },
            { "Phag", "pags-pa pismo" },
            { "Phli", "pisani pahlavi" },
            { "Phlp", "psalter pahlavi" },
            { "Phlv", "pahlavi pismo" },
            { "Phnx", "Feni\u010dansko pismo" },
            { "Plrd", "porald fonetsko pismo" },
            { "Prti", "pisani partian" },
            { "Rjng", "rejang pismo" },
            { "Rohg", "hanifi" },
            { "Roro", "rongorongo pismo" },
            { "Runr", "runsko pismo" },
            { "Samr", "samaritansko pismo" },
            { "Sara", "sarati pismo" },
            { "Saur", "saura\u0161tra pismo" },
            { "Sgnw", "znakovno pismo" },
            { "Shaw", "\u0161avijansko pismo" },
            { "Sinh", "sinhalsko pismo" },
            { "Sund", "sundansko pismo" },
            { "Sylo", "siloti nagri pismo" },
            { "Syrc", "sirijsko pismo" },
            { "Syre", "sirijsko estrangelo pismo" },
            { "Syrj", "zapadnosirijsko pismo" },
            { "Syrn", "pismo isto\u010dne Sirije" },
            { "Tagb", "tagbanva pismo" },
            { "Tale", "tai le pismo" },
            { "Talu", "novi tai lue" },
            { "Taml", "tamilsko pismo" },
            { "Tavt", "tai viet pismo" },
            { "Telu", "telugu pismo" },
            { "Teng", "tengvar pismo" },
            { "Tfng", "tifinag" },
            { "Tglg", "Tagalog" },
            { "Thaa", "tana pismo" },
            { "Thai", "tajlandsko pismo" },
            { "Tibt", "tibetansko pismo" },
            { "Ugar", "ugaritsko pismo" },
            { "Vaii", metaValue_vai },
            { "Visp", "vidljivi govor" },
            { "Xpeo", "staropersijsko pismo" },
            { "Xsux", "sumersko-akadsko kuneiform pismo" },
            { "Yiii", "ji" },
            { "Zinh", "nasledno pismo" },
            { "Zmth", "matemati\u010dka notacija" },
            { "Zsye", "emod\u017ei" },
            { "Zsym", "simboli" },
            { "Zxxx", "nepisani jezik" },
            { "Zyyy", "zajedni\u010dko pismo" },
            { "Zzzz", "nepoznato pismo" },
            { "de_AT", "austrijski nema\u010dki" },
            { "de_CH", "\u0161vajcarski visoki nema\u010dki" },
            { "en_GB", "engleski (Velika Britanija)" },
            { "en_US", "engleski (Sjedinjene Ameri\u010dke Dr\u017eave)" },
            { "es_ES", "\u0161panski (Evropa)" },
            { "fa_AF", "dari" },
            { "nl_BE", "flamanski" },
            { "pt_PT", "portugalski (Portugal)" },
            { "ro_MD", "moldavski" },
            { "sw_CD", "kisvahili" },
            { "%%1901", "Tradicionalna nema\u010dka ortografija" },
            { "%%1994", "Standardnizovana resijanska ortografija" },
            { "%%1996", "Nema\u010dka ortografija iz 1996" },
            { "ar_001", "savremeni standardni arapski" },
            { "key.ca", "kalendar" },
            { "key.cf", "format valute" },
            { "key.co", "redosled sortiranja" },
            { "key.cu", "valuta" },
            { "key.hc", "prikazivanje vremena (12- ili 24-\u010dasovno)" },
            { "key.lb", "stil preloma reda" },
            { "key.ms", "sistem mernih jedinica" },
            { "key.nu", "brojevi" },
            { "key.tz", "Vremenska zona" },
            { "key.va", "Varijanta lokaliteta" },
            { "nds_NL", "niskosaksonski" },
            { "%%BISKE", "San \u0110or\u0111io/Bila dijalekt" },
            { "%%BOONT", "Buntling" },
            { "%%LIPAW", "Lipovi\u010dki dijalekt resijanski" },
            { "%%NEDIS", "Natisone dijalekt" },
            { "%%NJIVA", "Gnjiva/Njiva dijalkekt" },
            { "%%OSOJS", "Oseako/Osojane dijalekt" },
            { "%%POSIX", "Kompjuter" },
            { "%%ROZAJ", "Resijan" },
            { "%%SAAHO", "Saho" },
            { "%%SOLBA", "Stolvica/Solbica dijalekt" },
            { "zh_Hans", "pojednostavljeni kineski" },
            { "zh_Hant", "tradicionalni kineski" },
            { "%%FONIPA", "IPA fonetika" },
            { "%%FONUPA", "UPA fonetika" },
            { "%%SCOUSE", "Skauz" },
            { "%%TARASK", "Taraskijevi\u010dka ortografija" },
            { "%%AREVELA", "Isto\u010dni armenijski" },
            { "%%AREVMDA", "Zapadno jermenska" },
            { "%%MONOTON", "Monotonik" },
            { "%%POLYTON", "Politonik" },
            { "%%REVISED", "Revidirana ortografija" },
            { "%%1606NICT", "Francuski iz kasnog srednjeg veka do 1606." },
            { "%%1694ACAD", "Rani moderni francuski" },
            { "%%BAKU1926", "Ujedinjen turski latini\u010dni alfabet" },
            { "%%SCOTLAND", "\u0160kotski standardni Engleski" },
            { "%%VALENCIA", "Valencijska" },
            { "type.ca.roc", "kalendar Republike Kine" },
            { "type.co.eor", "evropska pravila redosleda" },
            { "type.hc.h11", "12-\u010dasovni sistem (0-11)" },
            { "type.hc.h12", "12-\u010dasovni sistem (1-12)" },
            { "type.hc.h23", "24-\u010dasovni sistem (0-23)" },
            { "type.hc.h24", "24-\u010dasovni sistem (1-24)" },
            { "type.m0.bgn", "BGN (BGN)" },
            { "type.nu.arab", "arapsko-indijske cifre" },
            { "type.nu.armn", "jermenski brojevi" },
            { "type.nu.beng", "bengalske cifre" },
            { "type.nu.cakm", "\u010dakma cifre" },
            { "type.nu.deva", "devangari cifre" },
            { "type.nu.ethi", "etiopski brojevi" },
            { "type.nu.geor", "gruzijski brojevi" },
            { "type.nu.grek", "gr\u010dki brojevi" },
            { "type.nu.gujr", "gud\u017earatske cifre" },
            { "type.nu.guru", "gurmuki cifre" },
            { "type.nu.hans", "pojednostavljeni kineski brojevi" },
            { "type.nu.hant", "tradicionalni kineski brojevi" },
            { "type.nu.hebr", "hebrejski brojevi" },
            { "type.nu.java", "javanske cifre" },
            { "type.nu.jpan", "japanski brojevi" },
            { "type.nu.khmr", "kmerske cifre" },
            { "type.nu.knda", "kanada cifre" },
            { "type.nu.laoo", "lao\u0161ke cifre" },
            { "type.nu.latn", "zapadne cifre" },
            { "type.nu.mlym", "malajalam cifre" },
            { "type.nu.mong", "mongolske cifre" },
            { "type.nu.mtei", "mitei majek cifre" },
            { "type.nu.mymr", "mijanmarske cifre" },
            { "type.nu.olck", "ol \u010diki cifre" },
            { "type.nu.orya", "orija cifre" },
            { "type.nu.taml", "tamilski brojevi" },
            { "type.nu.telu", "telugu cifre" },
            { "type.nu.thai", "tajske cifre" },
            { "type.nu.tibt", "tibetanske cifre" },
            { "type.nu.vaii", "vai cifre" },
            { "type.ca.dangi", "dangi kalendar" },
            { "type.co.ducet", "podrazumevani Unicode redosled sortiranja" },
            { "type.lb.loose", "razmaknuti stil preloma reda" },
            { "type.nu.roman", "rimski brojevi" },
            { "type.ca.coptic", "koptski kalendar" },
            { "type.ca.hebrew", "hebrejski kalendar" },
            { "type.ca.indian", "Indijski nacionalni kalendar" },
            { "type.co.compat", "prethodni redosled sortiranja, zbog kompatibilnosti" },
            { "type.co.pinyin", "pinjin sortiranje" },
            { "type.co.search", "pretraga op\u0161te namene" },
            { "type.co.stroke", "sortiranje po broju poteza" },
            { "type.co.unihan", "redosled sortiranja radikalnih poteza" },
            { "type.co.zhuyin", "\u017eujin" },
            { "type.d0.fwidth", "puna \u0161irina" },
            { "type.d0.hwidth", "pola \u0161irine" },
            { "type.lb.normal", "normalni stil preloma reda" },
            { "type.lb.strict", "strogi stil preloma reda" },
            { "type.m0.ungegn", "UNGEGN (BGN)" },
            { "type.ms.metric", "metri\u010dki" },
            { "type.nu.native", "lokalne cifre" },
            { "type.ca.chinese", "kineski kalendar" },
            { "type.ca.islamic", "islamski kalendar" },
            { "type.ca.iso8601", "ISO-8601 kalendar" },
            { "type.ca.persian", "persijski kalendar" },
            { "type.cf.account", "ra\u010dunovodstveni format valute" },
            { "type.co.big5han", "tradicionalno kinesko sortiranje" },
            { "type.d0.npinyin", "Numeri\u010dka" },
            { "type.nu.arabext", "produ\u017eene arapsko-indijske cifre" },
            { "type.nu.armnlow", "mali jermenski brojevi" },
            { "type.nu.finance", "Finansijski brojevi" },
            { "type.nu.greklow", "mali gr\u010dki brojevi" },
            { "type.nu.hanidec", "kineski decimalni brojevi" },
            { "type.nu.hansfin", "pojednostavljeni kineski finansijski brojevi" },
            { "type.nu.hantfin", "tradicionalni kineski finansijski brojevi" },
            { "type.nu.jpanfin", "japanski finansijski brojevi" },
            { "type.nu.tamldec", "tamilske cifre" },
            { "type.ca.buddhist", "budisti\u010dki kalendar" },
            { "type.ca.ethiopic", "etiopski kalendar" },
            { "type.ca.japanese", "japanski kalendar" },
            { "type.cf.standard", "standardni format valute" },
            { "type.co.phonetic", "fonetski redosled sortiranja" },
            { "type.co.reformed", "reformisani redosled sortiranja" },
            { "type.co.searchjl", "Pretraga prema hangul po\u010detnom suglasniku" },
            { "type.co.standard", "standardni redosled sortiranja" },
            { "type.ms.uksystem", "imperijalni" },
            { "type.ms.ussystem", "ameri\u010dki" },
            { "type.nu.fullwide", "cifre pune \u0161irine" },
            { "type.nu.romanlow", "mali rimski brojevi" },
            { "type.ca.gregorian", "gregorijanski kalendar" },
            { "type.co.gb2312han", "pojednostavljeno kinesko sortiranje" },
            { "type.co.phonebook", "sortiranje kao telefonski imenik" },
            { "type.co.dictionary", "redosled sortiranja u re\u010dniku" },
            { "type.co.traditional", "tradicionalno sortiranje" },
            { "type.nu.traditional", "Tradicionalni brojevi" },
            { "type.ca.islamic-tbla", "islamski astronomski kalendar" },
            { "type.ca.islamic-civil", "islamski civilni kalendar" },
            { "type.ca.islamic-umalqura", "islamski kalendar (Umm al-Qura)" },
            { "type.ca.ethiopic-amete-alem", "etiopski amet alem kalendar" },
        };
        return data;
    }
}
